@@ -77,7 +77,7 @@ create_shader (int         type,
       buffer = g_malloc (log_len + 1);
       glGetShaderInfoLog (shader, log_len, NULL, buffer);
 
-      g_warning ("Compile failure in %s shader:\n%s\n",
+      g_warning ("Compile failure in %s shader:\n%s",
                  type == GL_VERTEX_SHADER ? "vertex" : "fragment",
                  buffer);
 
@@ -140,7 +140,7 @@ init_shaders (GLuint *program_out,
       buffer = g_malloc (log_len + 1);
       glGetProgramInfoLog (program, log_len, NULL, buffer);
 
-      g_warning ("Linking failure:\n%s\n", buffer);
+      g_warning ("Linking failure:\n%s", buffer);
 
       g_free (buffer);
 
@@ -220,6 +220,9 @@ realize (GtkWidget *widget)
 {
   gtk_gl_area_make_current (GTK_GL_AREA (widget));
 
+  if (gtk_gl_area_get_error (GTK_GL_AREA (widget)) != NULL)
+    return;
+
   init_buffers (&position_buffer, NULL);
   init_shaders (&program, &mvp_location);
 }
@@ -230,6 +233,9 @@ unrealize (GtkWidget *widget)
 {
   gtk_gl_area_make_current (GTK_GL_AREA (widget));
 
+  if (gtk_gl_area_get_error (GTK_GL_AREA (widget)) != NULL)
+    return;
+
   glDeleteBuffers (1, &position_buffer);
   glDeleteProgram (program);
 }
@@ -271,6 +277,9 @@ static gboolean
 render (GtkGLArea    *area,
         GdkGLContext *context)
 {
+  if (gtk_gl_area_get_error (area) != NULL)
+    return FALSE;
+
   /* Clear the viewport */
   glClearColor (0.5, 0.5, 0.5, 1.0);
   glClear (GL_COLOR_BUFFER_BIT);
@@ -364,7 +373,7 @@ create_glarea_window (GtkWidget *do_widget)
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_screen (GTK_WINDOW (window), gtk_widget_get_screen (do_widget));
-  gtk_window_set_title (GTK_WINDOW (window), "GtkGLArea - Golden Triangle");
+  gtk_window_set_title (GTK_WINDOW (window), "OpenGL Area");
   gtk_window_set_default_size (GTK_WINDOW (window), 400, 600);
   gtk_container_set_border_width (GTK_CONTAINER (window), 12);
   g_signal_connect (window, "destroy", G_CALLBACK (close_window), NULL);
