@@ -148,26 +148,6 @@ intern_atom_internal (const gchar *atom_name, gboolean allocate)
   return result;  
 }
 
-GdkAtom
-_gdk_quartz_display_manager_atom_intern (GdkDisplayManager *manager,
-                                         const gchar       *atom_name,
-                                         gboolean           copy_name)
-{
-  return intern_atom_internal (atom_name, copy_name);
-}
-
-gchar *
-_gdk_quartz_display_manager_get_atom_name (GdkDisplayManager *manager,
-                                           GdkAtom            atom)
-{
-  ensure_atom_tables ();
-
-  if (GPOINTER_TO_INT (atom) >= atoms_to_names->len)
-    return NULL;
-
-  return g_strdup (g_ptr_array_index (atoms_to_names, GPOINTER_TO_INT (atom)));
-}
-
 void
 _gdk_quartz_window_delete_property (GdkWindow *window,
                                     GdkAtom    property)
