@@ -232,7 +232,7 @@ _gdk_win32_display_open (const gchar *display_name)
 
   win32_display->screen = g_object_new (GDK_TYPE_WIN32_SCREEN, NULL);
 
-  _gdk_events_init ();
+  _gdk_events_init (_gdk_display);
 
   _gdk_input_ignore_core = FALSE;
 
