@@ -1118,10 +1118,6 @@ main (int argc, char **argv)
         model = create_list_blaat ();
         combobox = gtk_combo_box_new_with_model (model);
         g_object_unref (model);
-        g_object_set (combobox,
-                      "button-sensitivity", GTK_SENSITIVITY_OFF,
-                      //"model", NULL,
-                      NULL);
         gtk_container_add (GTK_CONTAINER (boom), combobox);
 
         renderer = gtk_cell_renderer_pixbuf_new ();
@@ -1323,10 +1319,6 @@ main (int argc, char **argv)
         comboboxtext = gtk_combo_box_text_new_with_entry ();
         setup_combo_entry (GTK_COMBO_BOX_TEXT (comboboxtext));
         gtk_container_add (GTK_CONTAINER (boom), comboboxtext);
-        g_object_set (comboboxtext,
-                      //"button-sensitivity", GTK_SENSITIVITY_OFF,
-                      "model", NULL,
-                      NULL);
 
 
         /* Phylogenetic tree */
