@@ -103,15 +103,36 @@ on_notebook_drag_begin (GtkWidget      *widget,
 
   if (page_num > 2)
     {
-      pixbuf = gtk_widget_render_icon_pixbuf (widget,
-                                              (page_num % 2) ? GTK_STOCK_HELP : GTK_STOCK_STOP,
-                                              GTK_ICON_SIZE_DND);
+      GtkIconTheme *icon_theme;
+      int width;
+
+      icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (widget));
+      gtk_icon_size_lookup (GTK_ICON_SIZE_DND, &width, NULL);
+      pixbuf = gtk_icon_theme_load_icon (icon_theme,
+                                         (page_num % 2) ? "help-browser" : "process-stop",
+                                         width,
+                                         GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+                                         NULL);
 
       gtk_drag_set_icon_pixbuf (context, pixbuf, 0, 0);
       g_object_unref (pixbuf);
     }
 }
 
+static gboolean
+remove_in_idle (gpointer data)
+{
+  GtkWidget *child = data;
+  GtkWidget *parent = gtk_widget_get_parent (child);
+  GtkWidget *tab_label;
+
+  tab_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (parent), child);
+  g_print ("Removing tab: %s\n", gtk_label_get_text (GTK_LABEL (tab_label)));
+  gtk_container_remove (GTK_CONTAINER (parent), child);
+
+  return G_SOURCE_REMOVE;
+}
+
 static void
 on_button_drag_data_received (GtkWidget        *widget,
                               GdkDragContext   *context,
@@ -122,16 +143,28 @@ on_button_drag_data_received (GtkWidget        *widget,
                               guint             time,
                               gpointer          user_data)
 {
-  GtkWidget *source, *tab_label;
   GtkWidget **child;
 
-  source = gtk_drag_get_source_widget (context);
   child = (void*) gtk_selection_data_get_data (data);
 
-  tab_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (source), *child);
-  g_print ("Removing tab: %s\n", gtk_label_get_text (GTK_LABEL (tab_label)));
+  g_idle_add (remove_in_idle, *child);
+}
 
-  gtk_container_remove (GTK_CONTAINER (source), *child);
+static void
+action_clicked_cb (GtkWidget *button,
+                   GtkWidget *notebook)
+{
+  GtkWidget *page, *title;
+
+  page = gtk_entry_new ();
+  gtk_entry_set_text (GTK_ENTRY (page), "Addition");
+  gtk_widget_show (page);
+
+  title = gtk_label_new ("Addition");
+
+  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, title);
+  gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK (notebook), page, TRUE);
+  gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (notebook), page, TRUE);
 }
 
 static GtkWidget*
@@ -139,12 +172,17 @@ create_notebook (gchar           **labels,
                  const gchar      *group,
                  GtkPositionType   pos)
 {
-  GtkWidget *notebook, *title, *page;
-  gint count = 0;
+  GtkWidget *notebook, *title, *page, *action_widget;
 
   notebook = gtk_notebook_new ();
   gtk_widget_set_vexpand (notebook, TRUE);
   gtk_widget_set_hexpand (notebook, TRUE);
+
+  action_widget = gtk_button_new_from_icon_name ("list-add-symbolic", GTK_ICON_SIZE_BUTTON);
+  g_signal_connect (action_widget, "clicked", G_CALLBACK (action_clicked_cb), notebook);
+  gtk_widget_show (action_widget);
+  gtk_notebook_set_action_widget (GTK_NOTEBOOK (notebook), action_widget, GTK_PACK_END);
+
   g_signal_connect (notebook, "create-window",
                     G_CALLBACK (window_creation_function), NULL);
 
@@ -164,7 +202,6 @@ create_notebook (gchar           **labels,
       gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK (notebook), page, TRUE);
       gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (notebook), page, TRUE);
 
-      count++;
       labels++;
     }
 
@@ -219,7 +256,7 @@ create_trash_button (void)
 {
   GtkWidget *button;
 
-  button = gtk_button_new_from_stock (GTK_STOCK_DELETE);
+  button = gtk_button_new_with_mnemonic ("_Delete");
 
   gtk_drag_dest_set (button,
                      GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_DROP,
